"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BatchCompletionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    SOURCE_DATASET_ID_FIELD_NUMBER: builtins.int
    COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    DATA_LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    JSON_OBJECT_FIELD_NUMBER: builtins.int
    JSON_SCHEMA_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    source_dataset_id: builtins.str
    data_logging_enabled: builtins.bool
    json_object: builtins.bool
    @property
    def completion_options(self) -> global___CompletionOptions: ...
    @property
    def json_schema(self) -> global___JsonSchema: ...
    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        source_dataset_id: builtins.str = ...,
        completion_options: global___CompletionOptions | None = ...,
        data_logging_enabled: builtins.bool = ...,
        json_object: builtins.bool = ...,
        json_schema: global___JsonSchema | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["StructuredOutput", b"StructuredOutput", "completion_options", b"completion_options", "json_object", b"json_object", "json_schema", b"json_schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["StructuredOutput", b"StructuredOutput", "completion_options", b"completion_options", "data_logging_enabled", b"data_logging_enabled", "json_object", b"json_object", "json_schema", b"json_schema", "model_uri", b"model_uri", "source_dataset_id", b"source_dataset_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["StructuredOutput", b"StructuredOutput"]) -> typing.Literal["json_object", "json_schema"] | None: ...

global___BatchCompletionRequest = BatchCompletionRequest

@typing.final
class CompletionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEMPERATURE_FIELD_NUMBER: builtins.int
    MAX_TOKENS_FIELD_NUMBER: builtins.int
    REASONING_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def reasoning_options(self) -> global___ReasoningOptions: ...
    def __init__(
        self,
        *,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        reasoning_options: global___ReasoningOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "reasoning_options", b"reasoning_options", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "reasoning_options", b"reasoning_options", "temperature", b"temperature"]) -> None: ...

global___CompletionOptions = CompletionOptions

@typing.final
class ReasoningOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ReasoningMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ReasoningModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ReasoningOptions._ReasoningMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REASONING_MODE_UNSPECIFIED: ReasoningOptions._ReasoningMode.ValueType  # 0
        DISABLED: ReasoningOptions._ReasoningMode.ValueType  # 1
        ENABLED_HIDDEN: ReasoningOptions._ReasoningMode.ValueType  # 2

    class ReasoningMode(_ReasoningMode, metaclass=_ReasoningModeEnumTypeWrapper): ...
    REASONING_MODE_UNSPECIFIED: ReasoningOptions.ReasoningMode.ValueType  # 0
    DISABLED: ReasoningOptions.ReasoningMode.ValueType  # 1
    ENABLED_HIDDEN: ReasoningOptions.ReasoningMode.ValueType  # 2

    MODE_FIELD_NUMBER: builtins.int
    mode: global___ReasoningOptions.ReasoningMode.ValueType
    def __init__(
        self,
        *,
        mode: global___ReasoningOptions.ReasoningMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mode", b"mode"]) -> None: ...

global___ReasoningOptions = ReasoningOptions

@typing.final
class JsonSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEMA_FIELD_NUMBER: builtins.int
    @property
    def schema(self) -> google.protobuf.struct_pb2.Struct: ...
    def __init__(
        self,
        *,
        schema: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["schema", b"schema"]) -> None: ...

global___JsonSchema = JsonSchema



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.containerregistry.v1.repository_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetRepositoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    repository_id: builtins.str
    """ID of the Repository resource to return.

    To get the repository ID use a [RepositoryService.List] request.
    """
    def __init__(
        self,
        *,
        repository_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["repository_id", b"repository_id"]) -> None: ...

global___GetRepositoryRequest = GetRepositoryRequest

@typing.final
class GetRepositoryByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    repository_name: builtins.str
    """Name of the Repository resource to return.

    To get the repository name use a [RepositoryService.List] request.
    """
    def __init__(
        self,
        *,
        repository_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["repository_name", b"repository_name"]) -> None: ...

global___GetRepositoryByNameRequest = GetRepositoryByNameRequest

@typing.final
class ListRepositoriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRY_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    registry_id: builtins.str
    """ID of the registry to list repositories in.

    To get the registry ID use a [RegistryService.List] request.
    """
    folder_id: builtins.str
    """ID of the folder to list registries in.

    [folder_id] is ignored if a [ListImagesRequest.registry_id] is specified in the request.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRepositoriesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListRepositoriesResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Repository.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    order_by: builtins.str
    def __init__(
        self,
        *,
        registry_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "registry_id", b"registry_id"]) -> None: ...

global___ListRepositoriesRequest = ListRepositoriesRequest

@typing.final
class ListRepositoriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORIES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRepositoriesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListRepositoriesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def repositories(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.containerregistry.v1.repository_pb2.Repository]:
        """List of Repository resources."""

    def __init__(
        self,
        *,
        repositories: collections.abc.Iterable[yandex.cloud.containerregistry.v1.repository_pb2.Repository] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "repositories", b"repositories"]) -> None: ...

global___ListRepositoriesResponse = ListRepositoriesResponse

@typing.final
class UpsertRepositoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the repository.

    The name of the repository should match the name of the images that will be pushed in the repository.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___UpsertRepositoryRequest = UpsertRepositoryRequest

@typing.final
class UpsertRepositoryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    repository_id: builtins.str
    """ID of the repository that is being upserted."""
    def __init__(
        self,
        *,
        repository_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["repository_id", b"repository_id"]) -> None: ...

global___UpsertRepositoryMetadata = UpsertRepositoryMetadata

@typing.final
class DeleteRepositoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    repository_id: builtins.str
    """ID of the repository to delete."""
    def __init__(
        self,
        *,
        repository_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["repository_id", b"repository_id"]) -> None: ...

global___DeleteRepositoryRequest = DeleteRepositoryRequest

@typing.final
class DeleteRepositoryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_ID_FIELD_NUMBER: builtins.int
    repository_id: builtins.str
    """ID of the repository that is being deleted."""
    def __init__(
        self,
        *,
        repository_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["repository_id", b"repository_id"]) -> None: ...

global___DeleteRepositoryMetadata = DeleteRepositoryMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.video.v1.manifest_pb2
import yandex.cloud.video.v1.video_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video to retrieve."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___GetVideoRequest = GetVideoRequest

@typing.final
class ListVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the videos to list."""
    page_size: builtins.int
    """The maximum number of videos to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListVideoResponse.
    """
    order_by: builtins.str
    """Specifies the ordering of results.
    Format is "<field> <order>" (e.g., "createdAt desc").
    Default: "id asc".
    Supported fields: ["id", "title", "createdAt", "updatedAt"].
    Both snake_case and camelCase field names are supported.
    """
    filter: builtins.str
    """Filter expression to narrow down the list of returned videos.
    Expressions consist of terms connected by logical operators.
    Values containing spaces or quotes must be enclosed in quotes (`'` or `"`)
    with inner quotes being backslash-escaped.

    Supported logical operators: ["AND", "OR"].
    Supported comparison operators: ["=", "!=", ":"] where ":" enables substring matching.
    Parentheses can be used to group logical expressions.

    Example: `title:'sample' AND (status='READY' OR visibilityStatus='PUBLISHED')`

    Filterable fields: ["id", "title", "status", "visibilityStatus"].
    Both snake_case and camelCase field names are supported.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListVideoRequest = ListVideoRequest

@typing.final
class ListVideoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEOS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def videos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.video_pb2.Video]:
        """List of videos matching the request criteria.
        May be empty if no videos match the criteria or if the channel is empty.
        """

    def __init__(
        self,
        *,
        videos: collections.abc.Iterable[yandex.cloud.video.v1.video_pb2.Video] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "videos", b"videos"]) -> None: ...

global___ListVideoResponse = ListVideoResponse

@typing.final
class BatchGetVideosRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    VIDEO_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the videos to retrieve."""
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of video IDs to retrieve."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "video_ids", b"video_ids"]) -> None: ...

global___BatchGetVideosRequest = BatchGetVideosRequest

@typing.final
class BatchGetVideosResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEOS_FIELD_NUMBER: builtins.int
    @property
    def videos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.video_pb2.Video]:
        """List of videos matching the requested IDs."""

    def __init__(
        self,
        *,
        videos: collections.abc.Iterable[yandex.cloud.video.v1.video_pb2.Video] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["videos", b"videos"]) -> None: ...

global___BatchGetVideosResponse = BatchGetVideosResponse

@typing.final
class CreateVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    AUTO_TRANSCODE_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    AUTO_PUBLISH_FIELD_NUMBER: builtins.int
    ENABLE_AD_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TUSD_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel where the video will be created."""
    title: builtins.str
    """Title of the video to be displayed in interfaces and players."""
    description: builtins.str
    """Detailed description of the video content and context.
    Optional field that can provide additional information about the video.
    """
    thumbnail_id: builtins.str
    """ID of the thumbnail image to be used for the video.
    If not provided, a thumbnail may be automatically generated during transcoding.
    """
    auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType
    """Controls whether transcoding starts automatically after upload.
    Set to ENABLE to automatically initiate transcoding after upload,
    or DISABLE for manual initiation via the Transcode() method.
    """
    style_preset_id: builtins.str
    """ID of the style preset to apply to the video during processing.
    Style presets define visual appearance settings for the video player.
    """
    @property
    def auto_publish(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether the video is automatically published after transcoding.
        When set to true, the video's visibility status will be set to PUBLISHED
        once transcoding is complete, making it available for watching.
        """

    @property
    def enable_ad(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls the ability to display advertisements for this video.
        Default: true
        Set explicitly to false to disable advertisements for this specific video.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom user-defined labels as `key:value` pairs.
        Maximum 64 labels per video.
        Keys must be lowercase alphanumeric strings with optional hyphens/underscores.
        Values can contain alphanumeric characters and various symbols.
        """

    @property
    def tusd(self) -> global___VideoTUSDParams:
        """Upload video using the TUS (Tus Resumable Upload Protocol) protocol.
        This is a push-based upload method where the client pushes data to the server.
        """

    @property
    def public_access(self) -> global___VideoPublicAccessParams:
        """Video is publicly available."""

    @property
    def sign_url_access(self) -> global___VideoSignURLAccessParams:
        """Access to the video is restricted by temporarily signed links."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType = ...,
        style_preset_id: builtins.str = ...,
        auto_publish: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_ad: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tusd: global___VideoTUSDParams | None = ...,
        public_access: global___VideoPublicAccessParams | None = ...,
        sign_url_access: global___VideoSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_publish", b"auto_publish", "enable_ad", b"enable_ad", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "tusd", b"tusd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_publish", b"auto_publish", "auto_transcode", b"auto_transcode", "channel_id", b"channel_id", "description", b"description", "enable_ad", b"enable_ad", "labels", b"labels", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "style_preset_id", b"style_preset_id", "thumbnail_id", b"thumbnail_id", "title", b"title", "tusd", b"tusd"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["tusd"] | None: ...

global___CreateVideoRequest = CreateVideoRequest

@typing.final
class VideoTUSDParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_SIZE_FIELD_NUMBER: builtins.int
    FILE_NAME_FIELD_NUMBER: builtins.int
    file_size: builtins.int
    """Total size of the file to be uploaded, in bytes."""
    file_name: builtins.str
    """Original name of the file being uploaded.
    This is used for reference and does not affect the upload process.
    """
    def __init__(
        self,
        *,
        file_size: builtins.int = ...,
        file_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_name", b"file_name", "file_size", b"file_size"]) -> None: ...

global___VideoTUSDParams = VideoTUSDParams

@typing.final
class VideoPublicAccessParams(google.protobuf.message.Message):
    """Parameters for video public access rights."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoPublicAccessParams = VideoPublicAccessParams

@typing.final
class VideoSignURLAccessParams(google.protobuf.message.Message):
    """Parameters for video access restrictions based on temporary signed links."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoSignURLAccessParams = VideoSignURLAccessParams

@typing.final
class CreateVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """Unique identifier of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___CreateVideoMetadata = CreateVideoMetadata

@typing.final
class UpdateVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    VIDEO_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    AUTO_TRANSCODE_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    ENABLE_AD_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video to update."""
    title: builtins.str
    """New title for the video."""
    description: builtins.str
    """New description for the video."""
    thumbnail_id: builtins.str
    """New thumbnail ID for the video."""
    auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType
    """New auto-transcoding setting for the video.
    Controls whether transcoding starts automatically after upload.
    """
    style_preset_id: builtins.str
    """New style preset ID for the video."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the video should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def enable_ad(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """New advertisement setting for the video.
        Set to false to disable advertisements for this specific video.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New custom labels for the video as `key:value` pairs.
        Maximum 64 labels per video.
        If provided, replaces all existing labels.
        """

    @property
    def public_access(self) -> global___VideoPublicAccessParams:
        """Makes the video publicly accessible to anyone with the direct link."""

    @property
    def sign_url_access(self) -> global___VideoSignURLAccessParams:
        """Restricts video access using URL signatures for secure time-limited access."""

    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType = ...,
        style_preset_id: builtins.str = ...,
        enable_ad: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        public_access: global___VideoPublicAccessParams | None = ...,
        sign_url_access: global___VideoSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "enable_ad", b"enable_ad", "field_mask", b"field_mask", "public_access", b"public_access", "sign_url_access", b"sign_url_access"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_transcode", b"auto_transcode", "description", b"description", "enable_ad", b"enable_ad", "field_mask", b"field_mask", "labels", b"labels", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "style_preset_id", b"style_preset_id", "thumbnail_id", b"thumbnail_id", "title", b"title", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...

global___UpdateVideoRequest = UpdateVideoRequest

@typing.final
class UpdateVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___UpdateVideoMetadata = UpdateVideoMetadata

@typing.final
class TranscodeVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    SUBTITLE_IDS_FIELD_NUMBER: builtins.int
    TRANSLATION_SETTINGS_FIELD_NUMBER: builtins.int
    SUMMARIZATION_SETTINGS_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video to transcode."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which transcoding-specific fields should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def subtitle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of manually uploaded subtitle files to include in the transcoding process.
        These subtitles will be embedded in the video output.
        """

    @property
    def translation_settings(self) -> global___VideoTranslationSettings:
        """Settings for automatic translation of audio tracks.
        Defines source tracks and target languages for subtitle and audio translation.
        """

    @property
    def summarization_settings(self) -> global___VideoSummarizationSettings:
        """Settings for automatic video content summarization.
        Defines which audio tracks should be processed to generate text summaries.
        """

    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        subtitle_ids: collections.abc.Iterable[builtins.str] | None = ...,
        translation_settings: global___VideoTranslationSettings | None = ...,
        summarization_settings: global___VideoSummarizationSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask", "summarization_settings", b"summarization_settings", "translation_settings", b"translation_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["field_mask", b"field_mask", "subtitle_ids", b"subtitle_ids", "summarization_settings", b"summarization_settings", "translation_settings", b"translation_settings", "video_id", b"video_id"]) -> None: ...

global___TranscodeVideoRequest = TranscodeVideoRequest

@typing.final
class VideoTranslationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TranslationTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INPUT_TRACK_FIELD_NUMBER: builtins.int
        SUBTITLES_FIELD_NUMBER: builtins.int
        AUDIO_FIELD_NUMBER: builtins.int
        @property
        def input_track(self) -> global___VideoTranslationSettings.InputTrack:
            """Input track settings."""

        @property
        def subtitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoTranslationSettings.SubtitleTrack]:
            """Settings for target subtitle tracks."""

        @property
        def audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoTranslationSettings.AudioTrack]:
            """Settings for target audio tracks."""

        def __init__(
            self,
            *,
            input_track: global___VideoTranslationSettings.InputTrack | None = ...,
            subtitles: collections.abc.Iterable[global___VideoTranslationSettings.SubtitleTrack] | None = ...,
            audio: collections.abc.Iterable[global___VideoTranslationSettings.AudioTrack] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["input_track", b"input_track"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["audio", b"audio", "input_track", b"input_track", "subtitles", b"subtitles"]) -> None: ...

    @typing.final
    class InputTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRACK_INDEX_FIELD_NUMBER: builtins.int
        SRC_LANG_FIELD_NUMBER: builtins.int
        track_index: builtins.int
        """Input audio track index (one-based)."""
        src_lang: builtins.str
        """Source track language represented as a three-letter code according to ISO 639-2/T.
        Track language will be deduced automatically if not provided.
        In the latter case the deduction accuracy is not guaranteed.
        For better performance please do specify the source track language when possible.
        """
        def __init__(
            self,
            *,
            track_index: builtins.int = ...,
            src_lang: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["src_lang", b"src_lang", "track_index", b"track_index"]) -> None: ...

    @typing.final
    class SubtitleTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DST_LANG_FIELD_NUMBER: builtins.int
        LABEL_FIELD_NUMBER: builtins.int
        dst_lang: builtins.str
        """Target language represented as a three-letter code according to ISO 639-2/T."""
        label: builtins.str
        """Track label to be displayed on the screen during video playback."""
        def __init__(
            self,
            *,
            dst_lang: builtins.str = ...,
            label: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["dst_lang", b"dst_lang", "label", b"label"]) -> None: ...

    @typing.final
    class AudioTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DST_LANG_FIELD_NUMBER: builtins.int
        LABEL_FIELD_NUMBER: builtins.int
        dst_lang: builtins.str
        """Target language represented as a three-letter code according to ISO 639-2/T."""
        label: builtins.str
        """Track label to be displayed on the screen during video playback."""
        def __init__(
            self,
            *,
            dst_lang: builtins.str = ...,
            label: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["dst_lang", b"dst_lang", "label", b"label"]) -> None: ...

    TRACKS_FIELD_NUMBER: builtins.int
    @property
    def tracks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoTranslationSettings.TranslationTrack]:
        """Translation settings for each track."""

    def __init__(
        self,
        *,
        tracks: collections.abc.Iterable[global___VideoTranslationSettings.TranslationTrack] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tracks", b"tracks"]) -> None: ...

global___VideoTranslationSettings = VideoTranslationSettings

@typing.final
class VideoSummarizationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SummarizationTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INPUT_TRACK_FIELD_NUMBER: builtins.int
        @property
        def input_track(self) -> global___VideoSummarizationSettings.InputTrack:
            """Input track settings."""

        def __init__(
            self,
            *,
            input_track: global___VideoSummarizationSettings.InputTrack | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["input_track", b"input_track"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["input_track", b"input_track"]) -> None: ...

    @typing.final
    class InputTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRACK_INDEX_FIELD_NUMBER: builtins.int
        SRC_LANG_FIELD_NUMBER: builtins.int
        track_index: builtins.int
        """Input audio track index (one-based)."""
        src_lang: builtins.str
        """Source track language represented as a three-letter code according to ISO 639-2/T.
        It will be deduced automatically if not provided.
        In the latter case the deduction accuracy is not guaranteed.
        For better performance please do specify the source track language when possible.
        """
        def __init__(
            self,
            *,
            track_index: builtins.int = ...,
            src_lang: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["src_lang", b"src_lang", "track_index", b"track_index"]) -> None: ...

    TRACKS_FIELD_NUMBER: builtins.int
    PROCESS_ALL_TRACKS_FIELD_NUMBER: builtins.int
    process_all_tracks: builtins.bool
    """Summarize all available tracks.
    If enabled, `tracks` parameter is ignored.
    Enables automatic source language deduction for each track
    and thus may lead to performance degradation.
    """
    @property
    def tracks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoSummarizationSettings.SummarizationTrack]:
        """Summarization settings for each track."""

    def __init__(
        self,
        *,
        tracks: collections.abc.Iterable[global___VideoSummarizationSettings.SummarizationTrack] | None = ...,
        process_all_tracks: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["process_all_tracks", b"process_all_tracks", "tracks", b"tracks"]) -> None: ...

global___VideoSummarizationSettings = VideoSummarizationSettings

@typing.final
class TranscodeVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___TranscodeVideoMetadata = TranscodeVideoMetadata

@typing.final
class DeleteVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video to delete."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___DeleteVideoRequest = DeleteVideoRequest

@typing.final
class DeleteVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video.
    This identifier can be used to track the video deletion operation.
    """
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___DeleteVideoMetadata = DeleteVideoMetadata

@typing.final
class BatchDeleteVideosRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    VIDEO_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the videos to delete."""
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of video IDs to delete."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "video_ids", b"video_ids"]) -> None: ...

global___BatchDeleteVideosRequest = BatchDeleteVideosRequest

@typing.final
class BatchDeleteVideosMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_IDS_FIELD_NUMBER: builtins.int
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of video IDs being deleted.
        This list can be used to track which videos are included
        in the batch deletion operation.
        """

    def __init__(
        self,
        *,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_ids", b"video_ids"]) -> None: ...

global___BatchDeleteVideosMetadata = BatchDeleteVideosMetadata

@typing.final
class PerformVideoActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    UNPUBLISH_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video on which to perform the action."""
    @property
    def publish(self) -> global___PublishVideoAction:
        """Publish the video, making it available for watching.
        Changes the video's visibility status to PUBLISHED.
        """

    @property
    def unpublish(self) -> global___UnpublishVideoAction:
        """Unpublish the video, making it unavailable for watching.
        Changes the video's visibility status to UNPUBLISHED.
        """

    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        publish: global___PublishVideoAction | None = ...,
        unpublish: global___UnpublishVideoAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "unpublish", b"unpublish"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "unpublish", b"unpublish", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["publish", "unpublish"] | None: ...

global___PerformVideoActionRequest = PerformVideoActionRequest

@typing.final
class PublishVideoAction(google.protobuf.message.Message):
    """Parameters for the publish action."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishVideoAction = PublishVideoAction

@typing.final
class UnpublishVideoAction(google.protobuf.message.Message):
    """Parameters for the unpublish action."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnpublishVideoAction = UnpublishVideoAction

@typing.final
class PerformVideoActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video on which the action is being performed.
    This identifier can be used to track the action operation
    and to verify that the action is being applied to the correct video.
    """
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___PerformVideoActionMetadata = PerformVideoActionMetadata

@typing.final
class GetVideoPlayerURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    SIGNED_URL_EXPIRATION_DURATION_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video for which to generate a player URL."""
    @property
    def params(self) -> global___VideoPlayerParams:
        """Optional player parameters to customize the playback experience.
        These parameters control initial player state such as mute, autoplay, and visibility of interface controls.
        """

    @property
    def signed_url_expiration_duration(self) -> google.protobuf.duration_pb2.Duration:
        """For episodes with signed URL access, specifies how long the generated URL will be valid.
        If not provided, a default expiration duration will be used.
        """

    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        params: global___VideoPlayerParams | None = ...,
        signed_url_expiration_duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration", "video_id", b"video_id"]) -> None: ...

global___GetVideoPlayerURLRequest = GetVideoPlayerURLRequest

@typing.final
class VideoPlayerParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTE_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    mute: builtins.bool
    """If true, the player will start with audio muted.
    Users can unmute the audio manually after playback starts.
    """
    autoplay: builtins.bool
    """If true, the video will start playing automatically when the player loads.
    This may be subject to browser autoplay policies that restrict autoplay with sound.
    """
    hidden: builtins.bool
    """If true, the player interface controls will be hidden initially.
    Users can typically reveal the controls by moving the mouse over the player.
    """
    def __init__(
        self,
        *,
        mute: builtins.bool = ...,
        autoplay: builtins.bool = ...,
        hidden: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["autoplay", b"autoplay", "hidden", b"hidden", "mute", b"mute"]) -> None: ...

global___VideoPlayerParams = VideoPlayerParams

@typing.final
class GetVideoPlayerURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URL_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    player_url: builtins.str
    """Direct URL to the video player.
    This URL can be used to access the video in a web browser
    or shared with users who have appropriate permissions.
    """
    html: builtins.str
    """HTML embed code in iframe format that can be inserted into web pages.
    This code allows the video to be embedded directly in third-party websites.
    """
    def __init__(
        self,
        *,
        player_url: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["html", b"html", "player_url", b"player_url"]) -> None: ...

global___GetVideoPlayerURLResponse = GetVideoPlayerURLResponse

@typing.final
class BatchGetVideoPlayerURLsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    VIDEO_IDS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    SIGNED_URL_EXPIRATION_DURATION_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the videos for which to generate player URLs."""
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of video IDs for which to generate player URLs."""

    @property
    def params(self) -> global___VideoPlayerParams:
        """Optional player parameters to customize the playback experience.
        These parameters control initial player state such as mute, autoplay, and visibility of interface controls.
        These parameters will be applied to all generated player URLs.
        """

    @property
    def signed_url_expiration_duration(self) -> google.protobuf.duration_pb2.Duration:
        """For episodes with signed URL access, specifies how long the generated URL will be valid.
        If not provided, a default expiration duration will be used.
        This setting applies to all videos in the batch that use sign_url_access.
        """

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
        params: global___VideoPlayerParams | None = ...,
        signed_url_expiration_duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration", "video_ids", b"video_ids"]) -> None: ...

global___BatchGetVideoPlayerURLsRequest = BatchGetVideoPlayerURLsRequest

@typing.final
class BatchGetVideoPlayerURLsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URLS_FIELD_NUMBER: builtins.int
    @property
    def player_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of player URLs corresponding to the requested video IDs.
        The order of URLs matches the order of video IDs in the request.
        """

    def __init__(
        self,
        *,
        player_urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["player_urls", b"player_urls"]) -> None: ...

global___BatchGetVideoPlayerURLsResponse = BatchGetVideoPlayerURLsResponse

@typing.final
class GetVideoManifestsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video for which to retrieve manifest URLs."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___GetVideoManifestsRequest = GetVideoManifestsRequest

@typing.final
class GetVideoManifestsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANIFESTS_FIELD_NUMBER: builtins.int
    @property
    def manifests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.manifest_pb2.Manifest]:
        """List of manifests available for the video.
        Different manifests may represent different streaming formats (e.g., HLS, DASH)
        """

    def __init__(
        self,
        *,
        manifests: collections.abc.Iterable[yandex.cloud.video.v1.manifest_pb2.Manifest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["manifests", b"manifests"]) -> None: ...

global___GetVideoManifestsResponse = GetVideoManifestsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/agent/agent.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/agent/agent.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.agent import status_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_status__pb2
from yandex.cloud.loadtesting.api.v1.agent import log_settings_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_log__settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/loadtesting/api/v1/agent/agent.proto\x12%yandex.cloud.loadtesting.api.v1.agent\x1a\x32yandex/cloud/loadtesting/api/v1/agent/status.proto\x1a\x38yandex/cloud/loadtesting/api/v1/agent/log_settings.proto\"\xb6\x03\n\x05\x41gent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x05 \x01(\t\x12=\n\x06status\x18\x07 \x01(\x0e\x32-.yandex.cloud.loadtesting.api.v1.agent.Status\x12\x0e\n\x06\x65rrors\x18\x08 \x03(\t\x12\x16\n\x0e\x63urrent_job_id\x18\t \x01(\t\x12\x18\n\x10\x61gent_version_id\x18\n \x01(\t\x12H\n\x06labels\x18\x0c \x03(\x0b\x32\x38.yandex.cloud.loadtesting.api.v1.agent.Agent.LabelsEntry\x12H\n\x0clog_settings\x18\r \x01(\x0b\x32\x32.yandex.cloud.loadtesting.api.v1.agent.LogSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07J\x04\x08\x0b\x10\x0c\x42|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.agent.agent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent'
  _globals['_AGENT_LABELSENTRY']._loaded_options = None
  _globals['_AGENT_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_AGENT']._serialized_start=203
  _globals['_AGENT']._serialized_end=641
  _globals['_AGENT_LABELSENTRY']._serialized_start=584
  _globals['_AGENT_LABELSENTRY']._serialized_end=629
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the Private cloud connection resource to return.

    To get the server ID, use a [PrivateCloudConnectionService.List] request.
    """
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___GetPrivateCloudConnectionRequest = GetPrivateCloudConnectionRequest

@typing.final
class ListPrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list private cloud connections in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListPrivateCloudConnectionResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListPrivateCloudConnectionResponse.next_page_token] returned by a previous list request.
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Supported fields: ["id", "createdAt", "updatedAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=` (equal), `:` (substring).
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["id", "name", "status", "vrfId", "routingInstanceId"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPrivateCloudConnectionRequest = ListPrivateCloudConnectionRequest

@typing.final
class ListPrivateCloudConnectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListPrivateCloudConnectionRequest.page_size], use `next_page_token` as the value
    for the [ListPrivateCloudConnectionRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def private_cloud_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection]:
        """List of Private cloud connection resources."""

    def __init__(
        self,
        *,
        private_cloud_connections: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "private_cloud_connections", b"private_cloud_connections"]) -> None: ...

global___ListPrivateCloudConnectionResponse = ListPrivateCloudConnectionResponse

@typing.final
class CreatePrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VRF_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of Cloud Router Routing Instance."""
    vrf_id: builtins.str
    """ID of VRF that is connected to routing Instance.

    To get the VRF ID, use a [VrfService.List] request.
    """
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        vrf_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id", "vrf_id", b"vrf_id"]) -> None: ...

global___CreatePrivateCloudConnectionRequest = CreatePrivateCloudConnectionRequest

@typing.final
class CreatePrivateCloudConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the private cloud connection that is being created."""
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___CreatePrivateCloudConnectionMetadata = CreatePrivateCloudConnectionMetadata

@typing.final
class UpdatePrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the private cloud connection to update.

    To get the private cloud connection ID, use a [PrivateCloudConnectionService.List] request.
    """
    routing_instance_id: builtins.str
    """ID of Cloud Router Routing Instance."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the PrivateCloudConnection resource are going to be updated."""

    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        routing_instance_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id", "routing_instance_id", b"routing_instance_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdatePrivateCloudConnectionRequest = UpdatePrivateCloudConnectionRequest

@typing.final
class UpdatePrivateCloudConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the Private cloud connection resource that is being update."""
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___UpdatePrivateCloudConnectionMetadata = UpdatePrivateCloudConnectionMetadata

@typing.final
class DeletePrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the private cloud connection to delete.

    To get the private cloud connection ID, use a [PrivateCloudConnectionService.List] request.
    """
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___DeletePrivateCloudConnectionRequest = DeletePrivateCloudConnectionRequest

@typing.final
class DeletePrivateCloudConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the Private cloud connection resource that is being deleted."""
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___DeletePrivateCloudConnectionMetadata = DeletePrivateCloudConnectionMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/pim/v1/saas/product_instance_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/pim/v1/saas/product_instance_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.marketplace.pim.v1.saas import product_instance_pb2 as yandex_dot_cloud_dot_marketplace_dot_pim_dot_v1_dot_saas_dot_product__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCyandex/cloud/marketplace/pim/v1/saas/product_instance_service.proto\x12$yandex.cloud.marketplace.pim.v1.saas\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a;yandex/cloud/marketplace/pim/v1/saas/product_instance.proto\"F\n\x19GetProductInstanceRequest\x12)\n\x13product_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x1b\x43laimProductInstanceRequest\x12\x1d\n\x05token\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x45\n\rresource_info\x18\x03 \x01(\x0b\x32..yandex.cloud.marketplace.pim.v1.saas.SaasInfo\"}\n\x1c\x43laimProductInstanceMetadata\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x1b\n\x13product_instance_id\x18\x02 \x01(\t\x12\x1b\n\x13license_instance_id\x18\x03 \x01(\t\x12\x0f\n\x07lock_id\x18\x04 \x01(\t2\xb2\x03\n\x16ProductInstanceService\x12\xbf\x01\n\x03Get\x12?.yandex.cloud.marketplace.pim.v1.saas.GetProductInstanceRequest\x1a\x35.yandex.cloud.marketplace.pim.v1.saas.ProductInstance\"@\x82\xd3\xe4\x93\x02:\x12\x38/marketplace/pim/saas/v1/instances/{product_instance_id}\x12\xd5\x01\n\x05\x43laim\x12\x41.yandex.cloud.marketplace.pim.v1.saas.ClaimProductInstanceRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*/\n\x1c\x43laimProductInstanceMetadata\x12\x0fProductInstance\x82\xd3\xe4\x93\x02-\"(/marketplace/pim/saas/v1/instances/claim:\x01*By\n(yandex.cloud.api.marketplace.pim.v1.saasZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/pim/v1/saas;saasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.pim.v1.saas.product_instance_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.marketplace.pim.v1.saasZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/pim/v1/saas;saas'
  _globals['_GETPRODUCTINSTANCEREQUEST'].fields_by_name['product_instance_id']._loaded_options = None
  _globals['_GETPRODUCTINSTANCEREQUEST'].fields_by_name['product_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLAIMPRODUCTINSTANCEREQUEST'].fields_by_name['token']._loaded_options = None
  _globals['_CLAIMPRODUCTINSTANCEREQUEST'].fields_by_name['token']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _globals['_PRODUCTINSTANCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PRODUCTINSTANCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002:\0228/marketplace/pim/saas/v1/instances/{product_instance_id}'
  _globals['_PRODUCTINSTANCESERVICE'].methods_by_name['Claim']._loaded_options = None
  _globals['_PRODUCTINSTANCESERVICE'].methods_by_name['Claim']._serialized_options = b'\262\322*/\n\034ClaimProductInstanceMetadata\022\017ProductInstance\202\323\344\223\002-\"(/marketplace/pim/saas/v1/instances/claim:\001*'
  _globals['_GETPRODUCTINSTANCEREQUEST']._serialized_start=305
  _globals['_GETPRODUCTINSTANCEREQUEST']._serialized_end=375
  _globals['_CLAIMPRODUCTINSTANCEREQUEST']._serialized_start=378
  _globals['_CLAIMPRODUCTINSTANCEREQUEST']._serialized_end=530
  _globals['_CLAIMPRODUCTINSTANCEMETADATA']._serialized_start=532
  _globals['_CLAIMPRODUCTINSTANCEMETADATA']._serialized_end=657
  _globals['_PRODUCTINSTANCESERVICE']._serialized_start=660
  _globals['_PRODUCTINSTANCESERVICE']._serialized_end=1094
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/configuration.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/configuration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.baremetal.v1alpha import disk_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/baremetal/v1alpha/configuration.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a)yandex/cloud/baremetal/v1alpha/disk.proto\"2\n\x03\x43PU\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\r\n\x05\x63ores\x18\x03 \x01(\x03\"\x80\x01\n\x16\x44iskDriveConfiguration\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.yandex.cloud.baremetal.v1alpha.DiskDriveType\x12\x12\n\ndisk_count\x18\x02 \x01(\x03\x12\x15\n\rdisk_size_gib\x18\x03 \x01(\x03\"\xf2\x01\n\rConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nmemory_gib\x18\x03 \x01(\x03\x12\x30\n\x03\x63pu\x18\x04 \x01(\x0b\x32#.yandex.cloud.baremetal.v1alpha.CPU\x12K\n\x0b\x64isk_drives\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.baremetal.v1alpha.DiskDriveConfiguration\x12\x1d\n\x15network_capacity_gbps\x18\x06 \x01(\x03\x12\x0f\n\x07\x63pu_num\x18\x08 \x01(\x03J\x04\x08\x07\x10\x08\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.configuration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_CPU']._serialized_start=129
  _globals['_CPU']._serialized_end=179
  _globals['_DISKDRIVECONFIGURATION']._serialized_start=182
  _globals['_DISKDRIVECONFIGURATION']._serialized_end=310
  _globals['_CONFIGURATION']._serialized_start=313
  _globals['_CONFIGURATION']._serialized_end=555
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/cluster_extension_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/cluster_extension_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import cluster_extension_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_cluster__extension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/mdb/clickhouse/v1/cluster_extension_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x36yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto\"d\n\x1aGetClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\x0e\x65xtension_name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\"~\n\x1cListClusterExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"~\n\x1dListClusterExtensionsResponse\x12\x44\n\nextensions\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.mdb.clickhouse.v1.ClusterExtension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x01\n\x1d\x43reateClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x0e\x65xtension_spec\x18\x02 \x01(\x0b\x32-.yandex.cloud.mdb.clickhouse.v1.ExtensionSpecB\x04\xe8\xc7\x31\x01\"L\n\x1e\x43reateClusterExtensionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x02 \x01(\t\"g\n\x1d\x44\x65leteClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\x0e\x65xtension_name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\"L\n\x1e\x44\x65leteClusterExtensionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x02 \x01(\t\"\x8e\x01\n\x1dUpdateClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x0e\x65xtension_spec\x18\x02 \x01(\x0b\x32-.yandex.cloud.mdb.clickhouse.v1.ExtensionSpecB\x04\xe8\xc7\x31\x01\"L\n\x1eUpdateClusterExtensionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x02 \x01(\t\"\x8f\x01\n\x1bSetClusterExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x0f\x65xtension_specs\x18\x02 \x03(\x0b\x32-.yandex.cloud.mdb.clickhouse.v1.ExtensionSpecB\x06\x82\xc8\x31\x02>0\"\x93\x01\n\x1cSetClusterExtensionsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1d\n\x15\x61\x64\x64\x65\x64_extension_names\x18\x02 \x03(\t\x12\x1f\n\x17updated_extension_names\x18\x03 \x03(\t\x12\x1f\n\x17\x64\x65leted_extension_names\x18\x04 \x03(\t\"<\n\rExtensionSpec\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x0f\n\x07version\x18\x02 \x01(\t2\xfd\n\n\x17\x43lusterExtensionService\x12\xc5\x01\n\x03Get\x12:.yandex.cloud.mdb.clickhouse.v1.GetClusterExtensionRequest\x1a\x30.yandex.cloud.mdb.clickhouse.v1.ClusterExtension\"P\x82\xd3\xe4\x93\x02J\x12H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}\x12\xc4\x01\n\x04List\x12<.yandex.cloud.mdb.clickhouse.v1.ListClusterExtensionsRequest\x1a=.yandex.cloud.mdb.clickhouse.v1.ListClusterExtensionsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-clickhouse/v1/clusters/{cluster_id}/extensions\x12\xe4\x01\n\x06\x43reate\x12=.yandex.cloud.mdb.clickhouse.v1.CreateClusterExtensionRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*2\n\x1e\x43reateClusterExtensionMetadata\x12\x10\x43lusterExtension\x82\xd3\xe4\x93\x02<\"7/managed-clickhouse/v1/clusters/{cluster_id}/extensions:\x01*\x12\xf8\x01\n\x06\x44\x65lete\x12=.yandex.cloud.mdb.clickhouse.v1.DeleteClusterExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*7\n\x1e\x44\x65leteClusterExtensionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02J*H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}\x12\xfb\x01\n\x06Update\x12=.yandex.cloud.mdb.clickhouse.v1.UpdateClusterExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*2\n\x1eUpdateClusterExtensionMetadata\x12\x10\x43lusterExtension\x82\xd3\xe4\x93\x02R2M/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_spec.name}:\x01*\x12\xf2\x01\n\rSetExtensions\x12;.yandex.cloud.mdb.clickhouse.v1.SetClusterExtensionsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*1\n\x1cSetClusterExtensionsMetadata\x12\x11\x43lusterExtensions\x82\xd3\xe4\x93\x02\x45\"@/managed-clickhouse/v1/clusters/{cluster_id}/extensions:batchSet:\x01*Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._loaded_options = None
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._loaded_options = None
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._serialized_options = b'\350\3071\001'
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._loaded_options = None
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._loaded_options = None
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._serialized_options = b'\350\3071\001'
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['extension_specs']._loaded_options = None
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['extension_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002J\022H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0029\0227/managed-clickhouse/v1/clusters/{cluster_id}/extensions'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*2\n\036CreateClusterExtensionMetadata\022\020ClusterExtension\202\323\344\223\002<\"7/managed-clickhouse/v1/clusters/{cluster_id}/extensions:\001*'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*7\n\036DeleteClusterExtensionMetadata\022\025google.protobuf.Empty\202\323\344\223\002J*H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*2\n\036UpdateClusterExtensionMetadata\022\020ClusterExtension\202\323\344\223\002R2M/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_spec.name}:\001*'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['SetExtensions']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['SetExtensions']._serialized_options = b'\262\322*1\n\034SetClusterExtensionsMetadata\022\021ClusterExtensions\202\323\344\223\002E\"@/managed-clickhouse/v1/clusters/{cluster_id}/extensions:batchSet:\001*'
  _globals['_GETCLUSTEREXTENSIONREQUEST']._serialized_start=289
  _globals['_GETCLUSTEREXTENSIONREQUEST']._serialized_end=389
  _globals['_LISTCLUSTEREXTENSIONSREQUEST']._serialized_start=391
  _globals['_LISTCLUSTEREXTENSIONSREQUEST']._serialized_end=517
  _globals['_LISTCLUSTEREXTENSIONSRESPONSE']._serialized_start=519
  _globals['_LISTCLUSTEREXTENSIONSRESPONSE']._serialized_end=645
  _globals['_CREATECLUSTEREXTENSIONREQUEST']._serialized_start=648
  _globals['_CREATECLUSTEREXTENSIONREQUEST']._serialized_end=790
  _globals['_CREATECLUSTEREXTENSIONMETADATA']._serialized_start=792
  _globals['_CREATECLUSTEREXTENSIONMETADATA']._serialized_end=868
  _globals['_DELETECLUSTEREXTENSIONREQUEST']._serialized_start=870
  _globals['_DELETECLUSTEREXTENSIONREQUEST']._serialized_end=973
  _globals['_DELETECLUSTEREXTENSIONMETADATA']._serialized_start=975
  _globals['_DELETECLUSTEREXTENSIONMETADATA']._serialized_end=1051
  _globals['_UPDATECLUSTEREXTENSIONREQUEST']._serialized_start=1054
  _globals['_UPDATECLUSTEREXTENSIONREQUEST']._serialized_end=1196
  _globals['_UPDATECLUSTEREXTENSIONMETADATA']._serialized_start=1198
  _globals['_UPDATECLUSTEREXTENSIONMETADATA']._serialized_end=1274
  _globals['_SETCLUSTEREXTENSIONSREQUEST']._serialized_start=1277
  _globals['_SETCLUSTEREXTENSIONSREQUEST']._serialized_end=1420
  _globals['_SETCLUSTEREXTENSIONSMETADATA']._serialized_start=1423
  _globals['_SETCLUSTEREXTENSIONSMETADATA']._serialized_end=1570
  _globals['_EXTENSIONSPEC']._serialized_start=1572
  _globals['_EXTENSIONSPEC']._serialized_end=1632
  _globals['_CLUSTEREXTENSIONSERVICE']._serialized_start=1635
  _globals['_CLUSTEREXTENSIONSERVICE']._serialized_end=3040
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.connectionmanager.v1.connection_pb2
import yandex.cloud.connectionmanager.v1.connection_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ConnectionServiceStub:
    """A set of methods for managing Connection resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.GetConnectionRequest,
        yandex.cloud.connectionmanager.v1.connection_pb2.Connection,
    ]
    """Returns connection."""

    ResolveCluster: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ResolveClusterRequest,
        yandex.cloud.connectionmanager.v1.connection_pb2.Connection,
    ]
    """Returns the connection with the resolved cluster; that is,
    * for connections to the on-premise clusters is identical to the Get RPC;
    * for connections to the managed clusters, resolves the cluster topology
      and returns it in the `on_premise` field of the connection parameters.
    Requires `connection-manager.connections.resolveCluster` permission.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListConnectionRequest,
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListConnectionResponse,
    ]
    """List connections in specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.CreateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates connection."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.UpdateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates specified connection."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.DeleteConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specified connection."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListOperationsRequest,
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListOperationsResponse,
    ]
    """Retrieves the list of Operation resources for the specified connection."""

class ConnectionServiceAsyncStub:
    """A set of methods for managing Connection resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.GetConnectionRequest,
        yandex.cloud.connectionmanager.v1.connection_pb2.Connection,
    ]
    """Returns connection."""

    ResolveCluster: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ResolveClusterRequest,
        yandex.cloud.connectionmanager.v1.connection_pb2.Connection,
    ]
    """Returns the connection with the resolved cluster; that is,
    * for connections to the on-premise clusters is identical to the Get RPC;
    * for connections to the managed clusters, resolves the cluster topology
      and returns it in the `on_premise` field of the connection parameters.
    Requires `connection-manager.connections.resolveCluster` permission.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListConnectionRequest,
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListConnectionResponse,
    ]
    """List connections in specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.CreateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates connection."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.UpdateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates specified connection."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.DeleteConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specified connection."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListOperationsRequest,
        yandex.cloud.connectionmanager.v1.connection_service_pb2.ListOperationsResponse,
    ]
    """Retrieves the list of Operation resources for the specified connection."""

class ConnectionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Connection resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.connectionmanager.v1.connection_service_pb2.GetConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.connectionmanager.v1.connection_pb2.Connection, collections.abc.Awaitable[yandex.cloud.connectionmanager.v1.connection_pb2.Connection]]:
        """Returns connection."""

    @abc.abstractmethod
    def ResolveCluster(
        self,
        request: yandex.cloud.connectionmanager.v1.connection_service_pb2.ResolveClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.connectionmanager.v1.connection_pb2.Connection, collections.abc.Awaitable[yandex.cloud.connectionmanager.v1.connection_pb2.Connection]]:
        """Returns the connection with the resolved cluster; that is,
        * for connections to the on-premise clusters is identical to the Get RPC;
        * for connections to the managed clusters, resolves the cluster topology
          and returns it in the `on_premise` field of the connection parameters.
        Requires `connection-manager.connections.resolveCluster` permission.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.connectionmanager.v1.connection_service_pb2.ListConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.connectionmanager.v1.connection_service_pb2.ListConnectionResponse, collections.abc.Awaitable[yandex.cloud.connectionmanager.v1.connection_service_pb2.ListConnectionResponse]]:
        """List connections in specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.connectionmanager.v1.connection_service_pb2.CreateConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates connection."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.connectionmanager.v1.connection_service_pb2.UpdateConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates specified connection."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.connectionmanager.v1.connection_service_pb2.DeleteConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete specified connection."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.connectionmanager.v1.connection_service_pb2.ListOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.connectionmanager.v1.connection_service_pb2.ListOperationsResponse, collections.abc.Awaitable[yandex.cloud.connectionmanager.v1.connection_service_pb2.ListOperationsResponse]]:
        """Retrieves the list of Operation resources for the specified connection."""

def add_ConnectionServiceServicer_to_server(servicer: ConnectionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cloudrouter.v1.routing_instance_pb2
import yandex.cloud.cloudrouter.v1.routing_instance_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RoutingInstanceServiceStub:
    """A set of methods for managing RoutingInstance resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the specified RoutingInstance resource.

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByVpcNetworkId: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByVpcNetworkIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by vpcNetworkId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByCicPrivateConnectionId: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by cicPrivateConnectionId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse,
    ]
    """Retrieves the list of RoutingInstance resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.CreateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a RoutingInstance resource in the specified folder using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a RoutingInstance resource using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpsertPrefixes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpsertPrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Upserts specified prefixes to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrefixes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified prefixes from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    MovePrefix: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.MovePrefixRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified prefix between availability zones of the RoutingInstance.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpdatePrefixMask: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdatePrefixMaskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    AddPrivateConnection: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.AddPrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds specified PrivateConnection to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrivateConnection: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.DeleteRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse,
    ]
    """Lists operations for the specified RoutingInstance."""

class RoutingInstanceServiceAsyncStub:
    """A set of methods for managing RoutingInstance resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the specified RoutingInstance resource.

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByVpcNetworkId: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByVpcNetworkIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by vpcNetworkId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByCicPrivateConnectionId: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by cicPrivateConnectionId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse,
    ]
    """Retrieves the list of RoutingInstance resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.CreateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a RoutingInstance resource in the specified folder using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a RoutingInstance resource using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpsertPrefixes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpsertPrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Upserts specified prefixes to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrefixes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified prefixes from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    MovePrefix: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.MovePrefixRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified prefix between availability zones of the RoutingInstance.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpdatePrefixMask: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdatePrefixMaskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    AddPrivateConnection: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.AddPrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds specified PrivateConnection to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrivateConnection: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.DeleteRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse,
    ]
    """Lists operations for the specified RoutingInstance."""

class RoutingInstanceServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing RoutingInstance resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance]]:
        """Returns the specified RoutingInstance resource.

        To get the list of available RoutingInstance resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetByVpcNetworkId(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByVpcNetworkIdRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance]]:
        """Returns the RoutingInstance resource by vpcNetworkId

        To get the list of available RoutingInstance resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetByCicPrivateConnectionId(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance]]:
        """Returns the RoutingInstance resource by cicPrivateConnectionId

        To get the list of available RoutingInstance resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse]]:
        """Retrieves the list of RoutingInstance resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.CreateRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a RoutingInstance resource in the specified folder using the data specified in the request.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdateRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates a RoutingInstance resource using the data specified in the request.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def UpsertPrefixes(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpsertPrefixesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Upserts specified prefixes to a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def RemovePrefixes(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrefixesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes specified prefixes from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def MovePrefix(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.MovePrefixRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified prefix between availability zones of the RoutingInstance.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def UpdatePrefixMask(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdatePrefixMaskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes specified PrivateConnection from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def AddPrivateConnection(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.AddPrivateConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds specified PrivateConnection to a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def RemovePrivateConnection(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrivateConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes specified PrivateConnection from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.DeleteRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse]]:
        """Lists operations for the specified RoutingInstance."""

def add_RoutingInstanceServiceServicer_to_server(servicer: RoutingInstanceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.speechsense.v1.talk_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TalkServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    UploadAsStream: grpc.StreamUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.StreamTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse,
    ]
    """rpc for streaming talk documents. First message should contain Talk related metadata,
    second - audio metadata, others should contain audio bytes in chunks
    """

    Upload: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse,
    ]
    """rpc for uploading talk document as single message"""

    UploadText: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTextRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTextResponse,
    ]
    """rpc for uploading text talk document"""

    UploadBadge: grpc.StreamUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.StreamTalkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """rpc for streaming document that contains combined talks. First message should contain Talk related metadata,
    second - audio metadata, others should contain audio bytes in chunks
    """

    Search: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.SearchTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.SearchTalkResponse,
    ]
    """rpc for searching talks. will return ids only"""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.GetTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.GetTalkResponse,
    ]
    """rpc for bulk get"""

class TalkServiceAsyncStub:
    UploadAsStream: grpc.aio.StreamUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.StreamTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse,
    ]
    """rpc for streaming talk documents. First message should contain Talk related metadata,
    second - audio metadata, others should contain audio bytes in chunks
    """

    Upload: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse,
    ]
    """rpc for uploading talk document as single message"""

    UploadText: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTextRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.UploadTextResponse,
    ]
    """rpc for uploading text talk document"""

    UploadBadge: grpc.aio.StreamUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.StreamTalkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """rpc for streaming document that contains combined talks. First message should contain Talk related metadata,
    second - audio metadata, others should contain audio bytes in chunks
    """

    Search: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.SearchTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.SearchTalkResponse,
    ]
    """rpc for searching talks. will return ids only"""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.talk_service_pb2.GetTalkRequest,
        yandex.cloud.speechsense.v1.talk_service_pb2.GetTalkResponse,
    ]
    """rpc for bulk get"""

class TalkServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadAsStream(
        self,
        request_iterator: _MaybeAsyncIterator[yandex.cloud.speechsense.v1.talk_service_pb2.StreamTalkRequest],
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse, collections.abc.Awaitable[yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse]]:
        """rpc for streaming talk documents. First message should contain Talk related metadata,
        second - audio metadata, others should contain audio bytes in chunks
        """

    @abc.abstractmethod
    def Upload(
        self,
        request: yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse, collections.abc.Awaitable[yandex.cloud.speechsense.v1.talk_service_pb2.UploadTalkResponse]]:
        """rpc for uploading talk document as single message"""

    @abc.abstractmethod
    def UploadText(
        self,
        request: yandex.cloud.speechsense.v1.talk_service_pb2.UploadTextRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.speechsense.v1.talk_service_pb2.UploadTextResponse, collections.abc.Awaitable[yandex.cloud.speechsense.v1.talk_service_pb2.UploadTextResponse]]:
        """rpc for uploading text talk document"""

    @abc.abstractmethod
    def UploadBadge(
        self,
        request_iterator: _MaybeAsyncIterator[yandex.cloud.speechsense.v1.talk_service_pb2.StreamTalkRequest],
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """rpc for streaming document that contains combined talks. First message should contain Talk related metadata,
        second - audio metadata, others should contain audio bytes in chunks
        """

    @abc.abstractmethod
    def Search(
        self,
        request: yandex.cloud.speechsense.v1.talk_service_pb2.SearchTalkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.speechsense.v1.talk_service_pb2.SearchTalkResponse, collections.abc.Awaitable[yandex.cloud.speechsense.v1.talk_service_pb2.SearchTalkResponse]]:
        """rpc for searching talks. will return ids only"""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.speechsense.v1.talk_service_pb2.GetTalkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.speechsense.v1.talk_service_pb2.GetTalkResponse, collections.abc.Awaitable[yandex.cloud.speechsense.v1.talk_service_pb2.GetTalkResponse]]:
        """rpc for bulk get"""

def add_TalkServiceServicer_to_server(servicer: TalkServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
